@@ -1,19 +1,20 @@
 #' Fortify method for classes from the sp package.
-#' 
-#' To figure out the correct variable name for region, inspect 
+#'
+#' To figure out the correct variable name for region, inspect
 #' \code{as.data.frame(model)}.
-#' 
+#'
 #' @param model \code{SpatialPolygonsDataFrame} to convert into a dataframe.
 #' @param data not used by this method
 #' @param region name of variable used to split up regions
 #' @param ... not used by this method
+#' @keywords internal
 #' @name fortify.sp
 #' @examples
 #' if (require("maptools")) {
 #'  sids <- system.file("shapes/sids.shp", package="maptools")
-#'  nc1 <- readShapePoly(sids, 
+#'  nc1 <- readShapePoly(sids,
 #'    proj4string = CRS("+proj=longlat +datum=NAD27"))
-#'  nc1_df <- fortify(nc1) 
+#'  nc1_df <- fortify(nc1)
 #' }
 NULL
 
@@ -24,14 +25,13 @@ fortify.SpatialPolygonsDataFrame <- function(model, data, region = NULL, ...) {
   attr <- as.data.frame(model)
   # If not specified, split into regions based on polygons
   if (is.null(region)) {
-    coords <- ldply(model@polygons,fortify)
+    coords <- plyr::ldply(model@polygons,fortify)
     message("Regions defined for each Polygons")
   } else {
-    cp <- polygons(model)
-    try_require("maptools")
+    cp <- sp::polygons(model)
 
     # Union together all polygons that make up a region
-    unioned <- unionSpatialPolygons(cp, attr[, region])
+    unioned <- maptools::unionSpatialPolygons(cp, attr[, region])
     coords <- fortify(unioned)
     coords$order <- 1:nrow(coords)
   }
@@ -42,7 +42,7 @@ fortify.SpatialPolygonsDataFrame <- function(model, data, region = NULL, ...) {
 #' @export
 #' @method fortify SpatialPolygons
 fortify.SpatialPolygons <- function(model, data, ...) {
-  ldply(model@polygons, fortify)
+  plyr::ldply(model@polygons, fortify)
 }
 
 #' @rdname fortify.sp
@@ -50,18 +50,17 @@ fortify.SpatialPolygons <- function(model, data, ...) {
 #' @method fortify Polygons
 fortify.Polygons <- function(model, data, ...) {
   subpolys <- model@Polygons
-  pieces <- ldply(seq_along(subpolys), function(i) {
+  pieces <- plyr::ldply(seq_along(subpolys), function(i) {
     df <- fortify(subpolys[[model@plotOrder[i]]])
     df$piece <- i
     df
   })
-  
-  within(pieces,{
-    order <- 1:nrow(pieces)
-    id <- model@ID
-    piece <- factor(piece)
-    group <- interaction(id, piece)
-  })
+
+  pieces$order <- 1:nrow(pieces)
+  pieces$id <- model@ID
+  pieces$piece <- factor(pieces$piece)
+  pieces$group <- interaction(pieces$id, pieces$piece)
+  pieces
 }
 
 #' @rdname fortify.sp
@@ -79,7 +78,7 @@ fortify.Polygon <- function(model, data, ...) {
 #' @export
 #' @method fortify SpatialLinesDataFrame
 fortify.SpatialLinesDataFrame <- function(model, data, ...) {
-  ldply(model@lines, fortify)
+  plyr::ldply(model@lines, fortify)
 }
 
 #' @rdname fortify.sp
@@ -87,18 +86,17 @@ fortify.SpatialLinesDataFrame <- function(model, data, ...) {
 #' @method fortify Lines
 fortify.Lines <- function(model, data, ...) {
   lines <- model@Lines
-  pieces <- ldply(seq_along(lines), function(i) {
+  pieces <- plyr::ldply(seq_along(lines), function(i) {
     df <- fortify(lines[[i]])
     df$piece <- i
     df
   })
-  
-  within(pieces,{
-    order <- 1:nrow(pieces)
-    id <- model@ID
-    piece <- factor(piece)
-    group <- interaction(id, piece)
-  })
+
+  pieces$order <- 1:nrow(pieces)
+  pieces$id <- model@ID
+  pieces$piece <- factor(pieces$piece)
+  pieces$group <- interaction(pieces$id, pieces$piece)
+  pieces
 }
 
 #' @rdname fortify.sp
@@ -108,5 +106,5 @@ fortify.Line <- function(model, data, ...) {
   df <- as.data.frame(model@coords)
   names(df) <- c("long", "lat")
   df$order <- 1:nrow(df)
-  df  
+  df
 }
