@@ -1,8 +1,8 @@
 #' Fortify a model with data.
 #'
-#' Method to convert a generic R object into a data frame useful for plotting.
-#' Takes its name from the idea of fortifying the original data with model fit
-#' statistics, and vice versa.
+#' Rather than using this function, I now recommend using the \pkg{broom}
+#' package, which implements a much wider range of methods. \code{fortify}
+#' may be deprecated in the future.
 #'
 #' @seealso \code{\link{fortify.lm}}
 #' @param model model or other R object to convert to data frame
@@ -16,7 +16,12 @@ fortify.data.frame <- function(model, data, ...) model
 #' @export
 fortify.NULL <- function(model, data, ...) waiver()
 #' @export
+fortify.function <- function(model, data, ...) model
+#' @export
 fortify.default <- function(model, data, ...) {
-
-  stop("ggplot2 doesn't know how to deal with data of class ", class(model), call. = FALSE)
+  stop(
+    "ggplot2 doesn't know how to deal with data of class ",
+    paste(class(model), collapse = "/"),
+    call. = FALSE
+  )
 }
