@@ -1,9 +1,15 @@
-#' Add heatmap of 2d bin counts.
+#' Heatmap of 2d bin counts
+#'
+#' Divides the plane into rectangles, counts the number of cases in
+#' each rectangle, and then (by default) maps the number of cases to the
+#' rectangle's fill. This is a useful alternative to \code{\link{geom_point}}
+#' in the presence of overplotting.
 #'
 #' @section Aesthetics:
-#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("stat", "bin2d")}
+#' \aesthetics{stat}{bin2d}
 #'
 #' @export
+#' @inheritParams layer
 #' @inheritParams geom_point
 #' @param geom,stat Use to override the default connection between
 #'   \code{geom_bin2d} and \code{stat_bin2d}.
@@ -19,9 +25,12 @@
 #'
 #' # Or by specifying the width of the bins
 #' d + geom_bin2d(binwidth = c(0.1, 0.1))
-geom_bin2d <- function(mapping = NULL, data = NULL, stat = "bin2d",
-                       position = "identity", na.rm = FALSE,
-                       show.legend = NA, inherit.aes = TRUE, ...) {
+geom_bin2d <- function(mapping = NULL, data = NULL,
+                       stat = "bin2d", position = "identity",
+                       ...,
+                       na.rm = FALSE,
+                       show.legend = NA,
+                       inherit.aes = TRUE) {
 
   layer(
     data = data,
