@@ -1,83 +1,76 @@
 # Grob for axes
-# 
+#
 # @param position of ticks
 # @param labels at ticks
 # @param position of axis (top, bottom, left or right)
 # @param range of data values
-guide_axis <- function(at, labels, position="right", theme) {
-  position <- match.arg(position, c("top", "bottom", "right", "left"))
+guide_axis <- function(at, labels, position = "right", theme) {
+  if (length(at) == 0)
+    return(zeroGrob())
 
-  # Quick fix for conflicts #297 and #118
-  # Previously, at = NA if there is no breaks (breaks = NA).
-  # Fix for oob bug changed so that at = numeric(0) if there is no breaks.
-  # Temporally, at is set as NA if there is no breaks.
-  # see also SHA: f332070fca77399a84ea7a116e8c63f6990abaf6, SHA: 2ae13ad0a856c24cab6a69b523da0936ef7a94d8
-  if (length(at) == 0) at <- NA
-  
   at <- unit(at, "native")
-  length <- theme$axis.ticks.length
-  label_pos <- length + theme$axis.ticks.margin
-
-  nticks <- length(at)
+  position <- match.arg(position, c("top", "bottom", "right", "left"))
 
   zero <- unit(0, "npc")
   one <- unit(1, "npc")
-  
+
   label_render <- switch(position,
-    top = , bottom = "axis.text.x",
-    left = , right = "axis.text.y"
+    top = "axis.text.x.top", bottom = "axis.text.x",
+    left = "axis.text.y", right = "axis.text.y.right"
   )
 
   label_x <- switch(position,
-    top = , 
+    top = ,
     bottom = at,
-    right = label_pos,
-    left = one - label_pos
+    right = theme$axis.ticks.length,
+    left = one - theme$axis.ticks.length
   )
   label_y <- switch(position,
-    top = label_pos, 
-    bottom = one - label_pos,
+    top = theme$axis.ticks.length,
+    bottom = one - theme$axis.ticks.length,
     right = ,
-    left = at,
+    left = at
   )
-  
+
   if (is.list(labels)) {
     if (any(sapply(labels, is.language))) {
       labels <- do.call(expression, labels)
     } else {
-      labels <- unlist(labels)    
+      labels <- unlist(labels)
     }
   }
 
   labels <- switch(position,
     top = ,
-    bottom = element_render(theme, label_render, labels, x = label_x),
+    bottom = element_render(theme, label_render, labels, x = label_x, expand_y = TRUE),
     right = ,
-    left =  element_render(theme, label_render, labels, y = label_y))
-  
+    left =  element_render(theme, label_render, labels, y = label_y, expand_x = TRUE))
+
   line <- switch(position,
     top =    element_render(theme, "axis.line.x", c(0, 1), c(0, 0), id.lengths = 2),
     bottom = element_render(theme, "axis.line.x", c(0, 1), c(1, 1), id.lengths = 2),
     right =  element_render(theme, "axis.line.y", c(0, 0), c(0, 1), id.lengths = 2),
     left =   element_render(theme, "axis.line.y", c(1, 1), c(0, 1), id.lengths = 2)
   )
-  
+
+  nticks <- length(at)
+
   ticks <- switch(position,
     top = element_render(theme, "axis.ticks.x",
-      x          = rep(at, each=2),
-      y          = rep(unit.c(zero, length), nticks),
+      x          = rep(at, each = 2),
+      y          = rep(unit.c(zero, theme$axis.ticks.length), nticks),
       id.lengths = rep(2, nticks)),
     bottom = element_render(theme, "axis.ticks.x",
-      x          = rep(at, each=2),
-      y          = rep(unit.c(one-length, one), nticks),
+      x          = rep(at, each = 2),
+      y          = rep(unit.c(one - theme$axis.ticks.length, one), nticks),
       id.lengths = rep(2, nticks)),
     right = element_render(theme, "axis.ticks.y",
-      x          = rep(unit.c(zero, length), nticks),
-      y          = rep(at, each=2),
+      x          = rep(unit.c(zero, theme$axis.ticks.length), nticks),
+      y          = rep(at, each = 2),
       id.lengths = rep(2, nticks)),
     left = element_render(theme, "axis.ticks.y",
-      x          = rep(unit.c(one-length, one), nticks),
-      y          = rep(at, each=2),
+      x          = rep(unit.c(one - theme$axis.ticks.length, one), nticks),
+      y          = rep(at, each = 2),
       id.lengths = rep(2, nticks))
   )
 
@@ -86,19 +79,23 @@ guide_axis <- function(at, labels, position="right", theme) {
     top    = gtable_col("axis",
       grobs   = list(labels, ticks),
       width   = one,
-      heights = unit.c(grobHeight(labels), label_pos)),
+      heights = unit.c(grobHeight(labels), theme$axis.ticks.length)
+    ),
     bottom = gtable_col("axis",
       grobs   = list(ticks, labels),
       width   = one,
-      heights = unit.c(label_pos, grobHeight(labels))),
+      heights = unit.c(theme$axis.ticks.length, grobHeight(labels))
+    ),
     right  = gtable_row("axis",
       grobs   = list(ticks, labels),
-      widths  = unit.c(label_pos, grobWidth(labels)),
-      height  = one),
+      widths  = unit.c(theme$axis.ticks.length, grobWidth(labels)),
+      height  = one
+    ),
     left   = gtable_row("axis",
       grobs   = list(labels, ticks),
-      widths  = unit.c(grobWidth(labels), label_pos),
-      height  = one)
+      widths  = unit.c(grobWidth(labels), theme$axis.ticks.length),
+      height  = one
+    )
   )
 
   # Viewport for justifying the axis grob
