@@ -1,7 +1,59 @@
-#' Theme element: blank.
-#' This theme element draws nothing, and assigns no space
+#' Theme elements
 #'
+#' @description
+#' In conjunction with the \link{theme} system, the \code{element_} functions
+#' specify the display of how non-data components of the plot are a drawn.
+#'
+#' \itemize{
+#'   \item \code{element_blank}: draws nothing, and assigns no space.
+#'   \item \code{element_rect}: borders and backgrounds.
+#'   \item \code{element_line}: lines.
+#'   \item \code{element_text}: text.
+#' }
+#'
+#' \code{rel()} is used to specify sizes relative to the parent,
+#' \code{margins()} is used to specify the margins of elements.
+#'
+#' @param fill Fill colour.
+#' @param colour,color Line/border colour. Color is an alias for colour.
+#' @param size Line/border size in mm; text size in pts.
+#' @param inherit.blank Should this element inherit the existence of an
+#'   \code{element_blank} among its parents? If \code{TRUE} the existence of
+#'   a blank element among its parents will cause this element to be blank as
+#'   well. If \code{FALSE} any blank parent element will be ignored when
+#'   calculating final element state.
+#' @return An S3 object of class \code{element}, \code{rel}, or \code{margin}.
+#' @examples
+#' plot <- ggplot(mpg, aes(displ, hwy)) + geom_point()
+#'
+#' plot + theme(
+#'   panel.background = element_blank(),
+#'   axis.text = element_blank()
+#' )
+#'
+#' plot + theme(
+#'   axis.text = element_text(colour = "red", size = rel(1.5))
+#' )
+#'
+#' plot + theme(
+#'   axis.line = element_line(arrow = arrow())
+#' )
+#'
+#' plot + theme(
+#'   panel.background = element_rect(fill = "white"),
+#'   plot.margin = margin(2, 2, 2, 2, "cm"),
+#'   plot.background = element_rect(
+#'     fill = "grey90",
+#'     colour = "black",
+#'     size = 1
+#'   )
+#' )
+#' @name element
+#' @aliases NULL
+NULL
+
 #' @export
+#' @rdname element
 element_blank <- function() {
   structure(
     list(),
@@ -9,72 +61,63 @@ element_blank <- function() {
   )
 }
 
-#' Theme element: rectangle.
-#'
-#' Most often used for backgrounds and borders.
-#'
-#' @param fill fill colour
-#' @param colour border colour
-#' @param size border size
-#' @param linetype border linetype
-#' @param color an alias for \code{colour}
 #' @export
+#' @rdname element
 element_rect <- function(fill = NULL, colour = NULL, size = NULL,
-  linetype = NULL, color = NULL) {
+  linetype = NULL, color = NULL, inherit.blank = FALSE) {
 
   if (!is.null(color))  colour <- color
   structure(
-    list(fill = fill, colour = colour, size = size, linetype = linetype),
+    list(fill = fill, colour = colour, size = size, linetype = linetype,
+         inherit.blank = inherit.blank),
     class = c("element_rect", "element")
   )
 }
 
-#' Theme element: line.
-#'
-#' @param colour line colour
-#' @param size line size
-#' @param linetype line type
-#' @param lineend line end
-#' @param color an alias for \code{colour}
 #' @export
+#' @rdname element
+#' @param linetype Line type. An integer (0:8), a name (blank, solid,
+#'    dashed, dotted, dotdash, longdash, twodash), or a string with
+#'    an even number (up to eight) of hexadecimal digits which give the
+#'    lengths in consecutive positions in the string.
+#' @param lineend Line end Line end style (round, butt, square)
+#' @param arrow Arrow specification, as created by \code{\link[grid]{arrow}}
 element_line <- function(colour = NULL, size = NULL, linetype = NULL,
-  lineend = NULL, color = NULL) {
+  lineend = NULL, color = NULL, arrow = NULL, inherit.blank = FALSE) {
 
   if (!is.null(color))  colour <- color
+  if (is.null(arrow)) arrow <- FALSE
   structure(
-    list(colour = colour, size = size, linetype = linetype, lineend = lineend),
+    list(colour = colour, size = size, linetype = linetype, lineend = lineend,
+      arrow = arrow, inherit.blank = inherit.blank),
     class = c("element_line", "element")
   )
 }
 
 
-#' Theme element: text.
-#'
-#' @param family font family
-#' @param face font face ("plain", "italic", "bold", "bold.italic")
-#' @param colour text colour
-#' @param size text size (in pts)
-#' @param hjust horizontal justification (in [0, 1])
-#' @param vjust vertical justification (in [0, 1])
-#' @param angle angle (in [0, 360])
-#' @param lineheight line height
-#' @param color an alias for \code{colour}
-#' @param margin margins around the text. See \code{\link{margin}} for more
+#' @param family Font family
+#' @param face Font face ("plain", "italic", "bold", "bold.italic")
+#' @param hjust Horizontal justification (in [0, 1])
+#' @param vjust Vertical justification (in [0, 1])
+#' @param angle Angle (in [0, 360])
+#' @param lineheight Line height
+#' @param margin Margins around the text. See \code{\link{margin}} for more
 #'   details. When creating a theme, the margins should be placed on the
 #'   side of the text facing towards the center of the plot.
 #' @param debug If \code{TRUE}, aids visual debugging by drawing a solid
 #'   rectangle behind the complete text area, and a point where each label
 #'   is anchored.
 #' @export
+#' @rdname element
 element_text <- function(family = NULL, face = NULL, colour = NULL,
   size = NULL, hjust = NULL, vjust = NULL, angle = NULL, lineheight = NULL,
-  color = NULL, margin = NULL, debug = NULL) {
+  color = NULL, margin = NULL, debug = NULL, inherit.blank = FALSE) {
 
   if (!is.null(color))  colour <- color
   structure(
     list(family = family, face = face, colour = colour, size = size,
       hjust = hjust, vjust = vjust, angle = angle, lineheight = lineheight,
-      margin = margin, debug = debug),
+      margin = margin, debug = debug, inherit.blank = inherit.blank),
     class = c("element_text", "element")
   )
 }
@@ -84,14 +127,8 @@ element_text <- function(family = NULL, face = NULL, colour = NULL,
 print.element <- function(x, ...) utils::str(x)
 
 
-#' Relative sizing for theme elements
-#'
-#' @param x A number representing the relative size
-#' @examples
-#' df <- data.frame(x = 1:3, y = 1:3)
-#' ggplot(df, aes(x, y)) +
-#'   geom_point() +
-#'   theme(axis.title.x = element_text(size = rel(2.5)))
+#' @param x A single number specifying size relative to parent element.
+#' @rdname element
 #' @export
 rel <- function(x) {
   structure(x, class = "rel")
@@ -102,6 +139,7 @@ print.rel <- function(x, ...) print(noquote(paste(x, " *", sep = "")))
 
 #' Reports whether x is a rel object
 #' @param x An object to test
+#' @keywords internal
 is.rel <- function(x) inherits(x, "rel")
 
 # Given a theme object and element name, return a grob for the element
@@ -114,7 +152,8 @@ element_render <- function(theme, element, ..., name = NULL) {
     return(zeroGrob())
   }
 
-  ggname(paste(element, name, sep = "."), element_grob(el, ...))
+  grob <- element_grob(el, ...)
+  ggname(paste(element, name, sep = "."), grob)
 }
 
 
@@ -195,11 +234,15 @@ element_grob.element_line <- function(element, x = 0:1, y = 0:1,
   gp <- gpar(lwd = len0_null(size * .pt), col = colour, lty = linetype, lineend = lineend)
   element_gp <- gpar(lwd = len0_null(element$size * .pt), col = element$colour,
     lty = element$linetype, lineend = element$lineend)
-
+  arrow <- if (is.logical(element$arrow) && !element$arrow) {
+    NULL
+  } else {
+    element$arrow
+  }
   polylineGrob(
     x, y, default.units = default.units,
     gp = utils::modifyList(element_gp, gp),
-    id.lengths = id.lengths, ...
+    id.lengths = id.lengths, arrow = arrow, ...
   )
 }
 
@@ -237,15 +280,22 @@ el_def <- function(class = NULL, inherit = NULL, description = NULL) {
   axis.line.x         = el_def("element_line", "axis.line"),
   axis.line.y         = el_def("element_line", "axis.line"),
   axis.text.x         = el_def("element_text", "axis.text"),
+  axis.text.x.top     = el_def("element_text", "axis.text.x"),
   axis.text.y         = el_def("element_text", "axis.text"),
+  axis.text.y.right   = el_def("element_text", "axis.text.y"),
   axis.ticks.length   = el_def("unit"),
   axis.ticks.x        = el_def("element_line", "axis.ticks"),
   axis.ticks.y        = el_def("element_line", "axis.ticks"),
   axis.title.x        = el_def("element_text", "axis.title"),
+  axis.title.x.top    = el_def("element_text", "axis.title.x"),
   axis.title.y        = el_def("element_text", "axis.title"),
+  axis.title.y.right  = el_def("element_text", "axis.title.y"),
 
   legend.background   = el_def("element_rect", "rect"),
-  legend.margin       = el_def("unit"),
+  legend.margin       = el_def("margin"),
+  legend.spacing      = el_def("unit"),
+  legend.spacing.x     = el_def("unit", "legend.spacing"),
+  legend.spacing.y     = el_def("unit", "legend.spacing"),
   legend.key          = el_def("element_rect", "rect"),
   legend.key.height   = el_def("unit", "legend.key.size"),
   legend.key.width    = el_def("unit", "legend.key.size"),
@@ -258,12 +308,15 @@ el_def <- function(class = NULL, inherit = NULL, description = NULL) {
   legend.justification = el_def("character"),
   legend.box          = el_def("character"),
   legend.box.just     = el_def("character"),
+  legend.box.margin   = el_def("margin"),
+  legend.box.background = el_def("element_rect", "rect"),
+  legend.box.spacing  = el_def("unit"),
 
   panel.background    = el_def("element_rect", "rect"),
   panel.border        = el_def("element_rect", "rect"),
-  panel.margin        = el_def("unit"),
-  panel.margin.x      = el_def("unit", "panel.margin"),
-  panel.margin.y      = el_def("unit", "panel.margin"),
+  panel.spacing       = el_def("unit"),
+  panel.spacing.x     = el_def("unit", "panel.spacing"),
+  panel.spacing.y     = el_def("unit", "panel.spacing"),
   panel.grid.major.x  = el_def("element_line", "panel.grid.major"),
   panel.grid.major.y  = el_def("element_line", "panel.grid.major"),
   panel.grid.minor.x  = el_def("element_line", "panel.grid.minor"),
@@ -273,11 +326,16 @@ el_def <- function(class = NULL, inherit = NULL, description = NULL) {
   strip.background    = el_def("element_rect", "rect"),
   strip.text.x        = el_def("element_text", "strip.text"),
   strip.text.y        = el_def("element_text", "strip.text"),
+  strip.placement     = el_def("character"),
+  strip.placement.x   = el_def("character", "strip.placement"),
+  strip.placement.y   = el_def("character", "strip.placement"),
   strip.switch.pad.grid = el_def("unit"),
   strip.switch.pad.wrap = el_def("unit"),
 
   plot.background     = el_def("element_rect", "rect"),
   plot.title          = el_def("element_text", "title"),
+  plot.subtitle       = el_def("element_text", "title"),
+  plot.caption        = el_def("element_text", "title"),
   plot.margin         = el_def("margin"),
 
   aspect.ratio        = el_def("character")
