@@ -3,7 +3,7 @@
 
   tips <- c(
     "Need help? Try the ggplot2 mailing list: http://groups.google.com/group/ggplot2.",
-    "Find out what's changed in ggplot2 at http://github.com/hadley/ggplot2/releases.",
+    "Find out what's changed in ggplot2 at http://github.com/tidyverse/ggplot2/releases.",
     "Use suppressPackageStartupMessages() to eliminate package startup messages.",
     "Stackoverflow is a great place to get help: http://stackoverflow.com/tags/ggplot2.",
     "Need help getting started? Try the cookbook for R: http://www.cookbook-r.com/Graphs/",
@@ -13,3 +13,9 @@
   tip <- sample(tips, 1)
   packageStartupMessage(paste(strwrap(tip), collapse = "\n"))
 }
+
+release_questions <- function() {
+  c(
+    "Have you built the book?"
+  )
+}
